@@ -9,9 +9,9 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.RecycleBin 1.21.23\nVersion:         1.21.23.post1\nBuilder"
-        " version: 7.4.1\nDocs:           "
-        " https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rbin//\nBoto3 docs:     "
+        "Type annotations for boto3.RecycleBin 1.21.30\nVersion:         1.21.30\nBuilder version:"
+        " 7.5.5\nDocs:            https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rbin//\nBoto3"
+        " docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rbin.html#RecycleBin\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
         " https://github.com/vemel/mypy_boto3_builder/releases"
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.21.23.post1")
+    print("1.21.30")
 
 
 def main() -> None:
